package com.roo.controller;

import com.roo.commons.log.annotation.LogOperation;
import com.roo.commons.tools.constant.Constant;
import com.roo.commons.tools.page.PageData;
import com.roo.commons.tools.utils.Result;
import com.roo.commons.tools.utils.ExcelUtils;
import com.roo.commons.tools.validator.AssertUtils;
import com.roo.commons.tools.validator.ValidatorUtils;
import com.roo.commons.tools.validator.group.AddGroup;
import com.roo.commons.tools.validator.group.DefaultGroup;
import com.roo.commons.tools.validator.group.UpdateGroup;
import com.roo.dto.ChainNodesDTO;
import com.roo.excel.ChainNodesExcel;
import com.roo.service.ChainNodesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
* RPC节点配置
*
* @author momin 460363410@qq.com
* @since 1.0 2021-07-02
*/
@RestController
@RequestMapping("chainnodes")
@Api(tags="RPC节点配置")
public class ChainNodesController {
    @Autowired
    private ChainNodesService chainNodesService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:page')")
    public Result<PageData<ChainNodesDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<ChainNodesDTO> page = chainNodesService.page(params);

        return new Result<PageData<ChainNodesDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:info')")
    public Result<ChainNodesDTO> get(@PathVariable("id") Long id){
        ChainNodesDTO data = chainNodesService.get(id);

        return new Result<ChainNodesDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:save')")
    public Result save(@RequestBody ChainNodesDTO dto){
        //效验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        chainNodesService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    @LogOperation("修改")
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:update')")
    public Result update(@RequestBody ChainNodesDTO dto){
        //效验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        chainNodesService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    @LogOperation("删除")
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:delete')")
    public Result delete(@RequestBody Long[] ids){
        //效验数据
        AssertUtils.isArrayEmpty(ids, "id");

        chainNodesService.delete(ids);

        return new Result();
    }

    @GetMapping("export")
    @ApiOperation("导出")
    @LogOperation("导出")
    @PreAuthorize("hasAuthority('chainnodes:chainnodes:export')")
    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
        List<ChainNodesDTO> list = chainNodesService.list(params);

        ExcelUtils.exportExcelToTarget(response, null, "RPC节点配置", list, ChainNodesExcel.class);
    }

}